==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/Snackbar.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
export let Snackbar = /*@__PURE__*/ (() => {
    class Snackbar extends BaseElement {
        constructor() {
            super(...arguments);
            this.b = new WCNativeHelper();
            this.g = null;
            this.action = null;
        }
        get c() {
            return this.b;
        }
        get nativeElement() {
            return this.g;
        }
        set nativeElement(a) {
            this.g = a;
            this.b.n = this.g;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get e() {
            let ret_ = this.c.m("open");
            return ret_;
        }
        set e(a) {
            let value_ = a;
            this.c.u("open", value_);
        }
        get f() {
            let ret_ = this.c.m("displayTime");
            return ret_;
        }
        set f(a) {
            let value_ = a;
            this.c.u("displayTime", value_);
        }
        get d() {
            let ret_ = this.c.m("keepOpen");
            return ret_;
        }
        set d(a) {
            let value_ = a;
            this.c.u("keepOpen", value_);
        }
        get i() {
            let ret_ = this.c.m("actionText");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.c.u("actionText", value_);
        }
        actionChanged() {
            if (this.action != null) {
                this.c.q("action", (a) => this.action(this, VoidEventArgs.b(a)));
            }
            else {
                this.c.t("action");
            }
        }
        m() {
            this.nativeElement.show();
        }
        k() {
            this.nativeElement.hide();
        }
        n() {
            this.nativeElement.toggle();
        }
    }
    Snackbar.$t = /*@__PURE__*/ markType(Snackbar, 'Snackbar', BaseElement.$);
    return Snackbar;
})();

==> igniteui-react-18.3.0-beta.0.tgz: package/esm2015/lib/Snackbar.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
export let Snackbar = /*@__PURE__*/ (() => {
    class Snackbar extends BaseElement {
        constructor() {
            super(...arguments);
            this.b = new WCNativeHelper();
            this.g = null;
            this.action = null;
        }
        get c() {
            return this.b;
        }
        get nativeElement() {
            return this.g;
        }
        set nativeElement(a) {
            this.g = a;
            this.b.o = this.g;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get e() {
            let ret_ = this.c.n("open");
            return ret_;
        }
        set e(a) {
            let value_ = a;
            this.c.v("open", value_);
        }
        get f() {
            let ret_ = this.c.n("displayTime");
            return ret_;
        }
        set f(a) {
            let value_ = a;
            this.c.v("displayTime", value_);
        }
        get d() {
            let ret_ = this.c.n("keepOpen");
            return ret_;
        }
        set d(a) {
            let value_ = a;
            this.c.v("keepOpen", value_);
        }
        get i() {
            let ret_ = this.c.n("actionText");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.c.v("actionText", value_);
        }
        actionChanged() {
            if (this.action != null) {
                this.c.r("action", (a) => this.action(this, VoidEventArgs.b(a)));
            }
            else {
                this.c.u("action");
            }
        }
        m() {
            this.nativeElement.show();
        }
        k() {
            this.nativeElement.hide();
        }
        n() {
            this.nativeElement.toggle();
        }
    }
    Snackbar.$t = /*@__PURE__*/ markType(Snackbar, 'Snackbar', BaseElement.$);
    return Snackbar;
})();
